# from selenium import webdriver
#
#
# class DriverUtil():
#     def __init__(self):
#         self.driver = webdriver.Chrome()
#
#     def start(self):
#         self.driver.get("http://eid.csrc.gov.cn/")
#         return self.driver