# import os
# from time import sleep
# from selenium import webdriver
# from framework.key_word.keyword_web import WebKeys
# import pytest
#
#
# @pytest.fixture(scope="function")
# def t():
#     t = webdriver.Chrome()
#     t.get("http://eid.csrc.gov.cn/")
#     sleep(3)
#     print("打开浏览器")
#
#     yield t
#     t.quit()
#
#
#
#
#
#
#
#
